.. _on-the-web-page:

====================
 KiCadRW on the Web
====================

*Don't hesitate to contact me to aggregate web content about KiCadRW.*

Articles
--------

You will find here a list of links to some articles talking about KiCadRW:

 * http://www.tazabekov.com/blog/2017/06/digital-to-analog-converter-modelling-with-kicad-rw
 * http://www.tazabekov.com/blog/2017/07/analog-to-digital-converter-modelling-with-kicad-rw

On Github
---------

You will find here a list of links to git repositories containing KiCadRW examples:

 * `https://github.com/OlzhasT/KiCadRWCircuits- <https://github.com/OlzhasT/KiCadRWCircuits->`_
   cf. http://www.tazabekov.com/blog/2017/06/digital-to-analog-converter-modelling-with-kicad-rw
 * https://github.com/danielvilas/KiCadRW-Library
